'use strict';

var gulp         = require('gulp'),
    autoprefixer = require('gulp-autoprefixer'),
    rename       = require('gulp-rename'),
    sourcemaps   = require('gulp-sourcemaps'),
    csso         = require('gulp-csso'),
    uglify       = require('gulp-uglify'),
    banner       = require('gulp-banner'),
    watch        = require('gulp-watch'),
    browserSync  = require('browser-sync'),
    del          = require('del'),
    pkg          = require('./package.json');

var comment = '/*\n' +
              ' * The jQuery plugin "uNav" v<%= pkg.version %>\n' +
              ' *\n' +
              ' * <%= pkg.homepage %>\n' +
              ' *\n' +
              ' * Copyright (c) 2017 <%= pkg.author %>\n' +
              ' *\n' +
              ' * Licensed under <%= pkg.license %>:\n' +
              ' *   https://github.com/Ins-V/uNav/blob/master/LICENSE.md\n' +
              ' *\n' +
              ' */\n\n';

var comment_min = '/* uNav v<%= pkg.version %> | Copyright (c) 2017 <%= pkg.author %> | Licensed under <%= pkg.license %> | <%= pkg.homepage %> */\n';

gulp.task('html', function(){
    return gulp.src('src/**/*.html')
            .pipe( gulp.dest('doc/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('css', function(){
    return gulp.src('src/style.unav.css')
            .pipe( autoprefixer(
                ['last 15 versions', '> 1%', 'ie 8', 'ie 7'],
                { cascade: true }
            ) )
            .pipe( banner(comment, { pkg: pkg }) )
            .pipe( gulp.dest('dist/css/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('css:min', function(){
    return gulp.src('src/style.unav.css')
            .pipe( sourcemaps.init() )
            .pipe( autoprefixer(
                ['last 15 versions', '> 1%', 'ie 8', 'ie 7'],
                { cascade: true }
            ) )
            .pipe( csso() )
            .pipe( banner(comment_min, { pkg: pkg }) )
            .pipe( rename({ suffix: '.min' }) )
            .pipe( sourcemaps.write('./') )
            .pipe( gulp.dest('dist/css/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('js', function(){
    return gulp.src('src/jquery.unav.js')
            .pipe( banner(comment, { pkg: pkg }) )
            .pipe( gulp.dest('dist/js/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('js:min', function(){
    return gulp.src('src/jquery.unav.js')
            .pipe( sourcemaps.init() )
            .pipe( uglify() )
            .pipe( banner(comment_min, { pkg: pkg }) )
            .pipe( rename({ suffix: '.min' }) )
            .pipe( sourcemaps.write('./') )
            .pipe( gulp.dest('dist/js/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('vendor', function(){
    return gulp.src('src/vendor/jquery/dist/jquery.js')
            .pipe( gulp.dest('dist/js/') )
            .pipe( browserSync.reload({stream: true}) );
});

gulp.task('clean', function(){
    return del.sync(['./dist', './doc']);
});

gulp.task('server', function(){
    browserSync({
        server: {
            baseDir: './doc',
            routes: {
            	'/dist': 'dist'
            }
        },
        notify: false,
        host: 'localhost',
        port: 3000,
        logPrefix: 'unav'
    });
});

gulp.task('build', [
    'html',
    'js',
    'css',
    'js:min',
    'css:min',
    'vendor'
]);

gulp.task('watch', function(){
    watch(['src/index.html'], function(event, cb){
        gulp.start('html');
    });

    watch(['src/style.unav.css'], function(event, cb){
        gulp.start('css');
    });
    
    watch(['src/jquery.unav.js'], function(event, cb){
        gulp.start('js');
    });
});

gulp.task('default', ['build', 'server', 'watch']);
